==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/CommandLine/ts/CommandLine_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+60"/>
        <source>&amp;Command Line</source>
        <translatorcomment>--google--
Aktywuj linię &amp;poleceń</translatorcomment>
        <translation type="unfinished">Command Line</translation>
    </message>
    <message>
        <location line="-30"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Aktywuj linię poleceń
Aktywuj linię &amp;poleceń</translatorcomment>
        <translation type="unfinished">Linia poleceń</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Nieprawidłowy koordynować&apos;&amp;#39;.</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nieznane polecenie lub nieprawidłowy współrzędnych lub wartość:&apos;&amp;#39;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Liczby mogą być wprowadzane jako:&apos;&amp;#39;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Współrzędne mogą być wpisane jako:&apos;&amp;#39; (absolutny) lub&amp;#39;&amp;#39; (względne) lub&amp;#39;&amp;#39; (polar) lub&amp;#39;&amp;#39; (względna polar)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Możesz zmienić numer / format współrzędnych w preferencjach aplikacji.</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked or invisible layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Próbuje zwrócić na lub modyfikować jednostki na warstwie zablokowanej lub niewidoczne.</translation>
    </message>
    <message>
        <location line="-317"/>
        <source>Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Invalid value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Warning</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Ostrzeżenie
Ostrzeżenie: %1</translatorcomment>
        <translation type="unfinished">Ostrzeżenie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Info</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Info
Informacja
Wypisuje informację debugowania obiektów</translatorcomment>
        <translation type="unfinished">Informacja</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Współrzędne
Współrzędne
Przyciągaj do danej współrzędnej</translatorcomment>
        <translation type="unfinished">Współrzędne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Aktywuj linię poleceń
Aktywuj linię &amp;poleceń</translatorcomment>
        <translation type="unfinished">Polecenie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Polecenie:
Odebrano komendę: %1 %2</translatorcomment>
        <translation type="unfinished">Polecenie:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Załadowany dokument:
Wersja: </translatorcomment>
        <translation type="unfinished">:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rozmiar Historia:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż ostrzeżenia jak Dialog</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż informacje jako dialog</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/CommandLine/ts/CommandLine_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+60"/>
        <source>&amp;Command Line</source>
        <translatorcomment>--google--
Aktywuj linię &amp;poleceń</translatorcomment>
        <translation>Wiersz p&amp;oleceń</translation>
    </message>
    <message>
        <location line="-30"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Aktywuj linię poleceń
Aktywuj linię &amp;poleceń</translatorcomment>
        <translation>Wiersz poleceń</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Nieprawidłowy koordynować&apos;&amp;#39;.</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nieznane polecenie lub nieprawidłowa współrzędna bądź wartość: „%1”</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Liczby mogą być wprowadzane jako: „%1”</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Współrzędne mogą być wprowadzane jako: „%1” (absolutnie), „%2” (względnie), „%3” (biegunowo) lub „%4”; (biegunowo względnie)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Format liczb i współrzędnych można zmienić w preferencjach programu.</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>Nieudana transakcja. Proszę sprawdzić rekurencję bloku oraz zablokowane lub niewidoczne warstwy lub bloki.</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked or invisible layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Próbuje zwrócić na lub modyfikować jednostki na warstwie zablokowanej lub niewidoczne.</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Widgets</source>
        <translation>Widżety</translation>
    </message>
    <message>
        <location line="+218"/>
        <source>Invalid value:</source>
        <translation>Nieprawidłowa wartość:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>Nieprawidłowa współrzędna lub odległość „%1”.</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Warning</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Ostrzeżenie
Ostrzeżenie: %1</translatorcomment>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Info</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Info
Informacja
Wypisuje informację debugowania obiektów</translatorcomment>
        <translation>Informacja</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Expression</source>
        <translation>Wyrażenie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Współrzędne
Współrzędne
Przyciągaj do danej współrzędnej</translatorcomment>
        <translation>Współrzędna</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Aktywuj linię poleceń
Aktywuj linię &amp;poleceń</translatorcomment>
        <translation>Polecenie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Polecenie:
Odebrano komendę: %1 %2</translatorcomment>
        <translation>Polecenie:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Załadowany dokument:
Wersja: </translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rozmiar historii:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ostrzeżenia w oknach dialogowych</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Informacje w oknach dialogowych</translation>
    </message>
</context>
</TS>
